@@ -3,7 +3,7 @@ package Acme::Bleach::Numerically;
 use 5.008001;
 use strict;
 use warnings;
-our $VERSION = sprintf "%d.%02d", q$Revision: 0.2 $ =~ /(\d+)/g;
+our $VERSION = sprintf "%d.%02d", q$Revision: 0.3 $ =~ /(\d+)/g;
 our $MAX_SIZE = 0x7fff_ffff;
 use Math::BigInt lib => 'GMP'; # faster if there, fallbacks if not
 use Math::BigFloat;
@@ -49,12 +49,13 @@ sub import{
 	}
     }else{ # bleach!
 	open my $in, "<:raw", $0 or die "$0 : $!";
-	my $src = join '', <$in>;
+	my $src = join '', grep !/use\s*Acme::Bleach::Numerically/, <$in>;
 	close $in;
+	warn $src;
 	if ($src =~ /^0\.[0-9]+;?\s*$/){ # bleached
-	    eval num2str($src);
+	    my $code = num2str($src);
+	    eval $code;
 	}else{                       # whiten
-	    $src =~ s/(use Acme::Bleach::Numerically;)/"#$1"/e;
 	    {
 		no warnings;
 		eval $src;
@@ -63,7 +64,6 @@ sub import{
 		    die $@;
 		}
 	    }
-	    $src =~ s/#use Acme::Bleach::Numerically;\n*//;
 	    open my $out, ">:raw", $0 or die "$0 : $!";
 	    print $out 
 		"use ", __PACKAGE__, ";\n", 
